#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `web_shortcuts` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-web-shortcuts",
    version = "7.0.406",
    description = "Web Shortcuts",
    long_description = 
"""

Enable shortcuts feature in the web client.
===========================================

Add a Shortcut icon in the systray in order to access the user's shortcuts (if any).

Add a Shortcut icon besides the views title in order to add/remove a shortcut.
    
""",
    url = "http://openerp.com",
    author = "OpenERP SA",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.web_shortcuts': ".",
    },
    packages = ["openerp.addons.web_shortcuts"],
    package_data = {
        'openerp.addons.web_shortcuts': ["i18n/*.po*","static/src/xml/web_shortcuts.xml","static/src/js/web_shortcuts.js","static/src/img/icon.png","i18n/hr.po","i18n/da.po","i18n/sl.po","i18n/ru.po","i18n/zh_TW.po","i18n/en_GB.po","i18n/cs.po","i18n/fi.po","i18n/pt_BR.po","i18n/ro.po","i18n/es.po","i18n/mn.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/bs.po","i18n/tr.po","i18n/de.po","i18n/lt.po","i18n/hu.po","i18n/vi.po","i18n/el.po","i18n/gl.po","i18n/mk.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/th.po","i18n/ar.po","i18n/pt.po","static/src/xml/*.xml","static/src/css/web_shortcuts.css","static/src/js/web_shortcuts.js"],
    },
    install_requires = ["openerp-core"],
    tests_require = ["unittest2"],
)
